#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部1章2節 \
#'   非線形最小２乗法の基本的な考え方 \
#'   Green3-1-2a.R
#' author: "Masahiko Katase"
#' date: "2021/4/28"
#' ---

library(readxl)

df <- read_excel("Green3-1.xlsx", sheet = "12-tankaiki")
df <- data.frame(df)

#'# 表示 1.2.6  (p.12), 表示 1.2.7 JMP による解析結果(p.13) 
# 非線形最小２乗法：線形モデル
 
nls_out1 <- nls(formula = y ~ a + b * x, 
                start = list(a = 5, 
                             b = 0.5),
                data = df, 
                trace = FALSE) 
plot.new()
par(mfrow = c(1, 1))
par(mar = c(4, 4, 1, 1))
plot(df$x, df$y)　　　　　　# 散布図と残差　　　　　
lines(df$x, fitted(nls_out1))
cbind("x" = df$x, "y" = df$y, "y-hat" = fitted(nls_out1),
      "e" = df$y - fitted(nls_out1))

pred1 <- predict(nls_out1)　# 残差
resi1 <- residuals(nls_out1)
cbind("x" = df$x, "y" = df$y, "y-hat" = pred1,
      "e" = resi1)

print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
confint(nls_out1)　　　　　 # 推定値の区間推定
deviance(nls_out1)          # 残差平方和 SSE
cov2cor(vcov(nls_out1))     # 推定値の相関

par(mfrow = c(1, 2)) 
plot(df$x, df$y, cex = 1)
lines(df$x, fitted(nls_out1), col = 2, lty = 2, lwd = 2)
plot(df$x, resid(nls_out1))

# 補足
lm_out <- lm(formula = y ~ x, data = df)
summary(lm_out)

#'# 表示 1.2.9 JMP による解析結果(p.15) 
# 非線形最小２乗法：逆推定（非線形モデル）

nls_out2 <- nls(formula = y ~ 8 + bb * (x - x8), 
                start = list(bb = 1, 
                             x8 = 6),
                data = df, 
                trace = FALSE) 

pred2 <- predict(nls_out2)　# 残差プロット
resi2 <- residuals(nls_out2)
cbind("x" = df$x, "y" = df$y, "y-hat" = pred2,
      "e" = resi2)

print(nls_out2)　　　　　　 # 結果の要約 
summary(nls_out2)           # 推定値、近似標準誤差、t値
confint(nls_out2)　　　　　 # 推定値の区間推定
deviance(nls_out2)          # 残差平方和 SSE
cov2cor(vcov(nls_out2))     # 推定値の相関
