#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部1章2節 \
#'   非線形最小２乗法の基本的な考え方 \
#'   Green3-1-2b.R
#' author: "Masahiko Katase"
#' date: "2021/3/15"
#' ---

library(readxl)

df <- read_excel("Green3-1.xlsx", sheet = "enshu122")
df <- data.frame(df)

#'# 表示 1.6.2 データり散布図と２次式のあてはめ、表示 1.6.3 JMP[非線形回帰]の解 (p.63)
# 非線形最小２乗法：２次式のあてはめ（非線形モデル）

plot.new()
par(mfrow = c(1, 1))
par(mar = c(4, 4, 1, 1))
plot(df$x, df$y)

# いずれかの「df1」を有効にする
#df1 <- subset(df, 2 <= x & x <= 8)    
 df1 <- subset(df, 0 <= x & x <= 6)

mdl <- y ~ yopt + b2 * (x - xopt)^2
nls_out1 <- nls(formula = mdl, 
                start = list(yopt = 35, 
                             xopt = 5,
                             b2   = -0.05),
                data = df1, 
                trace = FALSE) 

plot(df1$x, df1$y)　　　　　　# 散布図と残差プロット　　　　　
lines(df1$x, fitted(nls_out1))
cbind("x" = df1$x, "y" = df1$y, "y-hat" = fitted(nls_out1),
      "e" = df1$y - fitted(nls_out1))

pred1 <- predict(nls_out1)　# 残差プロット
resi1 <- residuals(nls_out1)
cbind("x" = df1$x, "y" = df1$y, "y-hat" = pred1,
      "e" = resi1)

print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
confint(nls_out1)　　　　　 # 推定値の区間推定
deviance(nls_out1)          # 残差平方和 SSE
cov2cor(vcov(nls_out1))     # 推定値の相関

# 補足：線形最小２乗法：２次式のあてはめ（線形モデル）
lm_out1 <- lm(y ~ poly(x, 2, raw = TRUE), data = df1)
summary(lm_out1)
             
lm_out2 <- lm(y ~ x + I(x^2), data = df1)
summary(lm_out2)
