#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部1章3節 \
#'   指数曲線のあてはめ \
#'   Green3-1-3a.R
#' author: "Masahiko Katase"
#' date: "2021/4/29"
#' ---

#'# 表示 1.3.1 y0=100、b<1 の場合 (p.27)
 
# 指数関数の定義
fexp1 <- function(x, y0, b) {y0 * b^x}

plot.new()
par(mfcol = c(1, 2))   
par(mar = c(4, 4, 1, 1)) 

# 指数曲線  
plot(NA, xlim = c(0, 10), ylim = c(0, 100),
     xlab = "x", ylab = "y")
for (i in 5:9) {
  curve(fexp1(x, y0 = 100, b = i / 10), 0, 10,
        ylim = c(0, 100), col = i - 4, add = TRUE)
}

# 指数曲線、縦軸を対数目盛に指定
plot(NA, xlim = c(0, 10), ylim = c(0.1, 100), log = "y",
     xlab = "x", ylab = "y 対数目盛")
for (i in 5:9) {
  curve(fexp1(x, y0 = 100, b = i / 10), 0, 10, 
        ylim = c(0.1, 100), col = i - 4, add = TRUE)
}

#'# 表示 1.3.2 静脈内投与後の血液中薬物量の時間推移 (p.29)

# 指数関数の定義
fexp2 <- function(x, y0, B) {y0 * exp(B * x)}

x2 <- c(0, 1, 2, 3, 5, 7, 10, 15, 20, 25, 30)
y2   <- fexp2(x2, 100, -0.1)
lny <- log(y2) 
cbind(x = x2, y = y2, lny = lny)

plot.new()
par(mfcol = c(1, 2))   
par(mar = c(4, 4, 1, 1)) 

plot(x2, y2, ylim = c(0, 100), type = "b", pch = 20)
plot(x2, lny, ylim = c(0, 5), type = "b", pch = 20)

#'# 表示 1.3.3 式（1.3.9）の曲線の変化（p.31）

# 指数関数の定義
fexp3 <- function(x, y0, yinf, b) {yinf + (y0 - yinf) * b^x}

x3 <- 0:10
y3 <- matrix(0, nrow = 11, ncol = 4)
yinf <- c(70, 70, 10, 10)
b3   <- c(0.5, 0.8, 0.8, 0.5)

for (i in 1:4) {
  y3[, i] <- fexp3(x3, 30, yinf[i], b3[i])
}

plot.new()
par(mfcol = c(1, 1))   
par(mar = c(4, 4, 1, 1)) 
plot(NA, xlim = c(0, 10), ylim = c(0, 70), xlab = "x", ylab = "y")
for (i in 1:4) {
  lines(x3, y3[, i], type = "b", col = i, lwd = 2)
}
abline(h = (1:7) * 10, v = 1, lty = 3, lwd = 1)