#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部1章3節 \
#'   指数曲線のあてはめ \
#'   Green3-1-3b.R
#' author: "Masahiko Katase"
#' date: "2021/4/29"
#' ---

library(readxl)

# df1 繰り返しがないデータ
# df2 繰り返しがあるデータ（個々の値）
# df3 繰り返しがあるデータ（平均値）
df1 <- read_excel("Green3-1.xlsx", sheet = "13-shisu1")
df2 <- read_excel("Green3-1.xlsx", sheet = "13-shisu2")
df3 <- read_excel("Green3-1.xlsx", sheet = "13-shisu3")
df1 <- data.frame(df1)
df2 <- data.frame(df2)
df3 <- data.frame(df3)

# model式
mdl1 <- y ~ yinf + (y0 - yinf) * exp(B * x)
mdl2 <- y ~ yinf + (0  - yinf) * exp(B * x)

#'# 表示 1.3.6 JMP による解析結果(p.35)

nls_out1 <- nls(formula = mdl1, 
                start = list(yinf = 22,
                             y0   = 3, 
                             B    = -0.1),
               data = df1) 
print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
confint(nls_out1)　　　　　 # 推定値の区間推定
cov2cor(vcov(nls_out1))     # 推定値の相関

#'# 表示 1.3.11 JMP の解(p.38)　個々の値についての解析

nls_out2 <- nls(formula = mdl2, 
                start = list(yinf = 22,
                             B = -0.1),
                data = df2) 

print(nls_out2)　　　　　　  
summary(nls_out2)           
confint(nls_out2)　　　　　 
cov2cor(vcov(nls_out2))     

#'# 表示 1.3.11 (p.38)　平均値についての解析

nls_out3 <- nls(formula = mdl2, 
                start = list(yinf = 22,
                             B = -0.1),
                weights = n,
                data = df3) 
print(nls_out3)　　　　　　  
summary(nls_out3)           
confint(nls_out3)　　　　　 
cov2cor(vcov(nls_out3))   