#' ---
#' title: |
#'   医薬品開発のための統計解析 第3部1章4節 \
#'   Emax モデルとロジスティック曲線 \
#'   Green3-1-4b.R
#' author: "Masahiko Katase"
#' date: "2021/3/15"
#' ---

library(readxl)

df1 <- read_excel("Green3-1.xlsx", sheet = "14-Logist1")
df2 <- read_excel("Green3-1.xlsx", sheet = "14-Logist2")
df1 <- data.frame(df1)
df2 <- data.frame(df2)

# mdl1：y0 ＝ 0 の Emaxモデル　データにdf1
# mdl2：y0 ≠  0 の Emaxモデル　データにdf2
mdl1 <- y ~ yinf / (1 + (x50 / x) ^ b)
mdl2 <- y ~ y0 + (yinf - y0) /  (1 + (x50 / x) ^ b)
  
#'# 表示1.4.4 JMP「非線形回帰」による解析（p.47）
# y0 ＝ 0 の Emaxモデル

# グラフ化（横軸の目盛を後から axix 関数で描画）
plot(log10(df1$x), df1$y, type = "p", xaxt = 'n', 
     xlab = "", ylab = "",xlim = c(-2, 3))
xc <- as.character(c(0.01, 0.1, 1, 10, 100, 1000))
axis(side = 1, at = -2:3, labels = xc)

# 非線形回帰分析
nls_out1 <- nls(formula = mdl1, 
                start = list(yinf = 170, 
                             x50 = 1.5, 
                             b = 1),
                data = df1) 

print(nls_out1)　　　　　　 # 結果の要約 
summary(nls_out1)           # 推定値、近似標準誤差、t値
confint(nls_out1)　　　　　 # 推定値の区間推定
cov2cor(vcov(nls_out1))     # 推定値の相関

# 推定値 y-hat と残差の計算
df <- round(df1, digits = 3)
cbind(df, 
      "y-hat" = predict(nls_out1), 
      "e" = df1$y - predict(nls_out1))

plot(log10(df1$x), df1$y, type = "p", xaxt = 'n', 
     xlab = "", ylab = "",xlim = c(-2, 3))
newd <- data.frame(x = seq(-2, 3, length = 200) )
lines(newd$x, predict(nls_out1, newdata = 10^newd))
xc <- as.character(c(0.01, 0.1, 1, 10, 100, 1000))
axis(side = 1, at = -2:3, labels = xc)

#'# 表示1.4.8 JMP 出力（p.52）
#　y0 ≠ 0 の Emaxモデル

nls_out2 <- nls(formula = mdl2, 
                start = list(yinf = 17, 
                             x50 = 15, 
                             b = 1,
                             y0 = 8.5),
                data = df2) 

print(nls_out2)　　　　　　 # 結果の要約 
summary(nls_out2)           # 推定値、近似標準誤差、t値
cov2cor(vcov(nls_out2))     # 推定値の相関

df <- round(df2, digits = 2)
cbind(df, 
      "y-hat" = predict(nls_out2), 
      "e" = df2$y - predict(nls_out2))